@@ -55,6 +55,9 @@ func init() {
 		RequiredTypes:  []string{"resource"},
 		RequiredLabels: []string{"aws_alb", "aws_elb", "aws_lb"},
 		CheckFunc: func(set result.Set, resourceBlock *block.Block, _ *hclcontext.Context) {
+			if resourceBlock.HasChild("load_balancer_type") && resourceBlock.GetAttribute("load_balancer_type").Equals("gateway") {
+				return
+			}
 			if internalAttr := resourceBlock.GetAttribute("internal"); internalAttr == nil {
 				set.Add(
 					result.New(resourceBlock).
