@@ -3,8 +3,7 @@ package test
 import (
 	"testing"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/checks"
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/tfsec/tfsec/internal/app/tfsec/rules"
 )
 
 func Test_AWSOutdatedSSLPolicy(t *testing.T) {
@@ -12,8 +11,8 @@ func Test_AWSOutdatedSSLPolicy(t *testing.T) {
 	var tests = []struct {
 		name                  string
 		source                string
-		mustIncludeResultCode scanner.RuleCode
-		mustExcludeResultCode scanner.RuleCode
+		mustIncludeResultCode string
+		mustExcludeResultCode string
 	}{
 		{
 			name: "check aws_alb_listener with outdated policy",
@@ -22,7 +21,7 @@ resource "aws_alb_listener" "my-resource" {
 	ssl_policy = "ELBSecurityPolicy-TLS-1-1-2017-01"
 	protocol = "HTTPS"
 }`,
-			mustIncludeResultCode: checks.AWSOutdatedSSLPolicy,
+			mustIncludeResultCode: rules.AWSOutdatedSSLPolicy,
 		},
 		{
 			name: "check aws_lb_listener with outdated policy",
@@ -31,7 +30,7 @@ resource "aws_lb_listener" "my-resource" {
 	ssl_policy = "ELBSecurityPolicy-TLS-1-1-2017-01"
 	protocol = "HTTPS"
 }`,
-			mustIncludeResultCode: checks.AWSOutdatedSSLPolicy,
+			mustIncludeResultCode: rules.AWSOutdatedSSLPolicy,
 		},
 		{
 			name: "check aws_alb_listener with ok policy",
@@ -40,7 +39,7 @@ resource "aws_alb_listener" "my-resource" {
 	ssl_policy = "ELBSecurityPolicy-TLS-1-2-2017-01"
 	protocol = "HTTPS"
 }`,
-			mustExcludeResultCode: checks.AWSOutdatedSSLPolicy,
+			mustExcludeResultCode: rules.AWSOutdatedSSLPolicy,
 		},
 	}
 
